.. _api:

*************
API Reference
*************

Core
====

.. automodule:: marshmallow_jsonapi
    :members:

Fields
======

.. automodule:: marshmallow_jsonapi.fields
    :members:

Flask
=====

.. automodule:: marshmallow_jsonapi.flask
    :members:

Exceptions
==========

.. automodule:: marshmallow_jsonapi.exceptions
    :members:

Utilities
=========

.. automodule:: marshmallow_jsonapi.utils
    :members:
